diff --git a/.htaccess b/.htaccess
new file mode 100644
index 0000000..441e1e4
--- /dev/null
+++ b/.htaccess
@@ -0,0 +1,4 @@
+
+Order Allow,Deny
+Deny from all
+
diff --git a/README.txt b/README.txt
index 35f339e..e57a453 100644
--- a/README.txt
+++ b/README.txt
@@ -16,7 +16,12 @@ matter).
Then, create two directories-- "p/" and "u/"-- that are accessible and
modifiable by your web-server user.
Finally, make a "res/config.php" file (from "res/config.example.php").
-Then, profit!
+
+If you're using a web-server that supports .htaccess files (Apache and the
+ilk), then you should be good from here. Otherwise, you should manually block
+the files referenced in "/.htaccess" and "res/.htaccess"-- for sample config
+of Lighttpd, read "docs/lighttpd.txt".
+
----------------------------------------
diff --git a/public_html/coin.php b/coin.php
similarity index 65%
rename from public_html/coin.php
rename to coin.php
index 720b155..5504c27 100644
--- a/public_html/coin.php
+++ b/coin.php
@@ -1,6 +1,6 @@
"https://HOSTNAME/",
+ "^/COPYING.txt$" => "https://HOSTNAME/",
+ "^/res/config.*$" => "https://HOSTNAME/",
+ "^/res/library.*$" => "https://HOSTNAME/",
+ "^/res/templates.*$" => "https://HOSTNAME/"
+ )
+
+... just make sure to change HOSTNAME to your actual hostname, and to change
+"^/" to whatever the root to your insert-coin instance is.
diff --git a/public_html/index.php b/index.php
similarity index 100%
rename from public_html/index.php
rename to index.php
diff --git a/public_html/mask.php b/mask.php
similarity index 67%
rename from public_html/mask.php
rename to mask.php
index 89e4346..cdbf0d0 100644
--- a/public_html/mask.php
+++ b/mask.php
@@ -1,6 +1,6 @@
HTML
// Create a general insert-coin webpage; relative path from rootdir
// for $image_path, and relative path from /resources/templates/
// for $template
function create_page($page_title, $template, $image_alt_text, $image_path)
{
- include(root("resources/templates/header.php"));
+ include(root("res/templates/header.php"));
?>
+ src="">
@@ -1,6 +1,6 @@
HTML
// Create a general insert-coin webpage; relative path from rootdir
-// for $image_path, and relative path from /resources/templates/
+// for $image_path, and relative path from /res/templates/
// for $template
function create_page($page_title, $template, $image_alt_text, $image_path)